Index: src/ia32/virtual-frame-ia32.h |
=================================================================== |
--- src/ia32/virtual-frame-ia32.h (revision 3920) |
+++ src/ia32/virtual-frame-ia32.h (working copy) |
@@ -339,12 +339,12 @@ |
Result CallLoadIC(RelocInfo::Mode mode); |
// Call keyed load IC. Key and receiver are found on top of the |
- // frame. They are not dropped. |
+ // frame. Both are dropped. |
Result CallKeyedLoadIC(RelocInfo::Mode mode); |
- // Call store IC. Name, value, and receiver are found on top of the |
- // frame. Receiver is not dropped. |
- Result CallStoreIC(); |
+ // Call store IC. If the load is contextual, value is found on top of the |
+ // frame. If not, value and receiver are on the frame. Both are dropped. |
+ Result CallStoreIC(Handle<String> name, bool is_contextual); |
// Call keyed store IC. Value, key, and receiver are found on top |
// of the frame. Key and receiver are not dropped. |